import React, { useEffect, useState } from 'react'
import { Link, useLocation } from 'react-router-dom'
import axios from 'axios'
import { API_BASE_URL, SITE_TITLE } from '../config'

const PostPage = () => {
  const [posts, setPosts] = useState([])

  const location = useLocation ()
  const query = new URLSearchParams (location.search)
  const tagsQuery = query.get ('tags') ?? ''
  // const anyFlg = query.get ('match') === 'any'
  const anyFlg = false
  const tags = tagsQuery.split (' ').filter (e => e !== '')
  document.title = `${ tags.join (anyFlg ? ' or ' : ' and ') } | ${ SITE_TITLE }`

  useEffect(() => {
    const fetchPosts = async () => {
      try {
        const response = await axios.get(`${ API_BASE_URL }/posts`, {
            params: { tags:   tags.join (','),
                      match:  (anyFlg ? 'any' : 'all') } })
        setPosts(response.data)
      } catch (error) {
        console.error('Failed to fetch posts:', error)
        setPosts([])
      }
    }
    fetchPosts()
  }, [location.search])

  return (
    <div className="flex flex-wrap gap-4 p-4">
      {posts.map (post => (
        <Link
          to={`/posts/${ post.id }`}
          key={post.id}
          className="w-40 h-40 overflow-hidden rounded-lg shadow-md hover:shadow-lg"
        >
          <img
            src={post.thumbnail}
            className="object-none w-full h-full"
          />
        </Link>
      ))}
    </div>
  )
}

export default PostPage
